@@ -5,6 +5,16 @@
 Module to manage the AppMesh Virtual service
 """
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Mapping
+
+if TYPE_CHECKING:
+    from .appmesh_mesh import Mesh
+    from .appmesh_node import MeshNode
+    from .appmesh_router import MeshRouter
+    from ecs_composex.common.settings import ComposeXSettings
+
 from compose_x_common.compose_x_common import keyisset
 from troposphere import AWS_NO_VALUE, GetAtt, Ref, Select, Split, Sub, appmesh
 from troposphere.servicediscovery import DnsConfig as SdDnsConfig
@@ -14,7 +24,16 @@ from troposphere.servicediscovery import Service as SdService
 
 from ecs_composex.appmesh import appmesh_conditions
 from ecs_composex.appmesh.appmesh_params import NODE_KEY, ROUTER_KEY, ROUTERS_KEY
-from ecs_composex.common import NONALPHANUM
+from ecs_composex.cloudmap.cloudmap_params import (
+    PRIVATE_DNS_ZONE_NAME,
+    PRIVATE_NAMESPACE_ID,
+)
+from ecs_composex.common import (
+    NONALPHANUM,
+    add_parameters,
+    add_resource,
+    add_update_mapping,
+)
 
 
 def validate_service_backend(service, routers, nodes):
@@ -47,7 +66,15 @@ class MeshService:
     Class to represent a mesh Virtual Service.
     """
 
-    def __init__(self, name, definition, routers, nodes, mesh, settings):
+    def __init__(
+        self,
+        name: str,
+        definition: dict,
+        routers: Mapping[str, MeshRouter],
+        nodes: Mapping[str, MeshNode],
+        mesh: Mesh,
+        settings: ComposeXSettings,
+    ):
         """
         Method to initialize the Mesh service.
 
@@ -58,6 +85,9 @@ class MeshService:
         """
         self.title = NONALPHANUM.sub("", name)
         self.definition = definition
+        self._namespace = settings.find_resource(
+            f"x-cloudmap::{self.definition['x-cloudmap']}"
+        )
         service_node = (
             nodes[self.definition[NODE_KEY]]
             if keyisset(NODE_KEY, self.definition)
@@ -79,16 +109,18 @@ class MeshService:
         self.service = appmesh.VirtualService(
             f"{NONALPHANUM.sub('', name).title()}VirtualService",
             DependsOn=depends,
-            MeshName=appmesh_conditions.get_mesh_name(mesh),
+            MeshName=appmesh_conditions.get_mesh_name(mesh.appmesh),
             MeshOwner=appmesh_conditions.set_mesh_owner_id(),
             VirtualServiceName=Sub(
                 f"{name}.${{ZoneName}}",
-                ZoneName=settings.private_zone.name_value,
+                ZoneName=self.namespace_property(
+                    PRIVATE_DNS_ZONE_NAME, mesh.stack, settings
+                ),
             ),
             Spec=appmesh.VirtualServiceSpec(
                 Provider=appmesh.VirtualServiceProvider(
                     VirtualNode=appmesh.VirtualNodeServiceProvider(
-                        VirtualNodeName=service_node.get_node_param
+                        VirtualNodeName=GetAtt(service_node.node, "VirtualNodeName")
                     )
                     if service_node
                     else Ref(AWS_NO_VALUE),
@@ -103,18 +135,33 @@ class MeshService:
             ),
         )
 
-    def add_dns_entries(self, template, settings):
+    def namespace_property(self, property_param, stack, settings: ComposeXSettings):
+        if not self._namespace:
+            return Ref(AWS_NO_VALUE)
+        _id = self._namespace.attributes_outputs[property_param]
+        if self._namespace.cfn_resource:
+            add_parameters(stack.stack_template, [_id["ImportParameter"]])
+            stack.Parameters.update({_id["ImportParameter"].title: _id["ImportValue"]})
+            return Ref(_id["ImportParameter"])
+        elif self._namespace.mappings:
+            add_update_mapping(
+                stack.stack_template,
+                self._namespace.module.mapping_key,
+                settings.mappings[self._namespace.module.mapping_key],
+            )
+            return _id["ImportValue"]
+
+    def add_dns_entries(self, stack, settings):
         """
         Method to add CloudMap service and record for DNS resolution.
         """
         sd_entry = SdService(
             f"{self.title.title()}ServiceDiscovery",
-            template=template,
             DependsOn=[self.service.title],
             Description=Sub(
                 f"Record for VirtualService {self.title} in mesh ${{{self.service.title}.MeshName}}"
             ),
-            NamespaceId=settings.private_zone.id_value,
+            NamespaceId=self.namespace_property(PRIVATE_NAMESPACE_ID, stack, settings),
             DnsConfig=SdDnsConfig(
                 RoutingPolicy="MULTIVALUE",
                 NamespaceId=Ref(AWS_NO_VALUE),
@@ -122,12 +169,13 @@ class MeshService:
             ),
             Name=Select(0, Split(".", GetAtt(self.service, "VirtualServiceName"))),
         )
-        SdInstance(
+        instance = SdInstance(
             f"{self.title.title()}ServiceDiscoveryFakeInstance",
-            template=template,
             InstanceAttributes={"AWS_INSTANCE_IPV4": "169.254.255.254"},
             ServiceId=Ref(sd_entry),
         )
+        add_resource(stack.stack_template, sd_entry)
+        add_resource(stack.stack_template, instance)
 
     def get_backend_nodes(self):
         """
