@@ -1,6 +1,5 @@
-﻿#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Module to create the ElasticCache Cluster and nodes
@@ -169,7 +168,8 @@ def create_cluster_from_parameters(cluster, template):
         key in required_keys for key in cluster.parameters
     ):
         raise KeyError(
-            "When using MacroParameters only, you must specify at least", required_keys
+            "When using MacroParameters only, you must specify at least",
+            required_keys,
         )
     props = {
         "CacheNodeType": "cache.t3.small"
