@@ -3,7 +3,7 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, List, Union
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from ecs_composex.s3.s3_bucket import Bucket
